@@ -17,10 +17,10 @@ embed.aov <- function(x, ina) {
   Rbi <- sqrt( Rfast::rowsums(S^2) ) ## the mean resultant length of each group
   S <- Rfast::colmeans(x)
   Rbar <- sqrt( sum(S^2) )  ## the mean resultant length based on all the data
-  Ft <-  (n - g) * (p - 1) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( (g - 1) * (p - 1) * ( n - sum(ni * Rbi^2) ) )
+  Ft <-  (n - g) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( (g - 1) * ( n - sum(ni * Rbi^2) ) )
   pvalue <- pf(Ft, (g - 1) * (p - 1), (n - g) * (p - 1), lower.tail = FALSE)
   res <- c(Ft, pvalue)
-  names(res) <- c('F', 'p-value')
+  names(res) <- c('test', 'p-value')
   res
 }
 
